summaryrefslogtreecommitdiff
path: root/Build
diff options
context:
space:
mode:
authorKhaled Hosny <khaledhosny@eglug.org>2013-03-07 23:07:27 +0000
committerKhaled Hosny <khaledhosny@eglug.org>2013-03-07 23:07:27 +0000
commitff0c4e73858f75ead37fa8d5f31ca28025ba49ef (patch)
treec8da1044c572c2e16e6529605b0111b03f7ba225 /Build
parent116934fbf0f866176ca6e2360f10134c1da4eea7 (diff)
More XeTeX updates
git-svn-id: svn://tug.org/texlive/trunk@29307 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build')
-rw-r--r--Build/source/texk/web2c/xetexdir/XeTeXFontMgr.h4
-rw-r--r--Build/source/texk/web2c/xetexdir/XeTeX_ext.c38
-rw-r--r--Build/source/texk/web2c/xetexdir/XeTeX_ext.h23
-rw-r--r--Build/source/texk/web2c/xetexdir/XeTeX_mac.c2
-rw-r--r--Build/source/texk/web2c/xetexdir/xetex.ch2
-rw-r--r--Build/source/texk/web2c/xetexdir/xetex.defines14
-rw-r--r--Build/source/texk/web2c/xetexdir/xetex.web92
7 files changed, 88 insertions, 87 deletions
diff --git a/Build/source/texk/web2c/xetexdir/XeTeXFontMgr.h b/Build/source/texk/web2c/xetexdir/XeTeXFontMgr.h
index 6eb57eddcf3..a40c6143b4d 100644
--- a/Build/source/texk/web2c/xetexdir/XeTeXFontMgr.h
+++ b/Build/source/texk/web2c/xetexdir/XeTeXFontMgr.h
@@ -65,14 +65,14 @@ public:
PlatformFontRef findFont(const char* name, char* variant, double ptSize);
// 1st arg is name as specified by user (C string, UTF-8)
- // 2nd is /B/I/AAT/OT/ICU[/GR]/S=## qualifiers
+ // 2nd is /B/I/AAT/OT/ICU/GR/S=## qualifiers
// 1. try name given as "full name"
// 2. if there's a hyphen, split and try "family-style"
// 3. try as PostScript name
// 4. try name as family with "Regular/Plain/Normal" style
// apply style qualifiers and optical sizing if present
- // SIDE EFFECT: sets sReqEngine to 'A' or 'O' [or 'G'] if appropriate,
+ // SIDE EFFECT: sets sReqEngine to 'A' or 'O' or 'G' if appropriate,
// else clears it to 0
// SIDE EFFECT: updates TeX variables /nameoffile/ and /namelength/,
diff --git a/Build/source/texk/web2c/xetexdir/XeTeX_ext.h b/Build/source/texk/web2c/xetexdir/XeTeX_ext.h
index 2abedb38d7e..9faf51cc519 100644
--- a/Build/source/texk/web2c/xetexdir/XeTeX_ext.h
+++ b/Build/source/texk/web2c/xetexdir/XeTeX_ext.h
@@ -55,9 +55,6 @@ typedef struct UFILE* unicodefile;
#define FONT_FLAGS_COLORED 0x01
#define FONT_FLAGS_VERTICAL 0x02
-#define kXeTeXEmboldenTag 0x10000 /* user-defined ATSUAttributeTag to carry 'embolden' value */
-
-
/* some typedefs that XeTeX uses - on Mac OS, we get these from Apple headers,
but otherwise we'll need these substitute definitions */
@@ -76,7 +73,7 @@ typedef uint32_t OTTag;
typedef uint16_t GlyphID;
-/* these are also in xetex-new.ch and must correspond! */
+/* these are also in xetex.web and must correspond! */
#define pdfbox_crop 1
#define pdfbox_media 2
@@ -117,7 +114,7 @@ typedef uint16_t GlyphID;
#define XeTeX_selector_name 9
-/* definitions used to access info in a native_word_node; must correspond with defines in xetex-new.ch */
+/* definitions used to access info in a native_word_node; must correspond with defines in xetex.web */
#define width_offset 1
#define depth_offset 2
#define height_offset 3
@@ -275,14 +272,14 @@ extern "C" {
typedef void* CFDictionaryRef; /* dummy declaration just so the stubs can compile */
#endif
- int atsufontget(int what, CFDictionaryRef attrs);
- int atsufontget1(int what, CFDictionaryRef attrs, int param);
- int atsufontget2(int what, CFDictionaryRef attrs, int param1, int param2);
- int atsufontgetnamed(int what, CFDictionaryRef attrs);
- int atsufontgetnamed1(int what, CFDictionaryRef attrs, int param);
- void atsuprintfontname(int what, CFDictionaryRef attrs, int param1, int param2);
+ int aatfontget(int what, CFDictionaryRef attrs);
+ int aatfontget1(int what, CFDictionaryRef attrs, int param);
+ int aatfontget2(int what, CFDictionaryRef attrs, int param1, int param2);
+ int aatfontgetnamed(int what, CFDictionaryRef attrs);
+ int aatfontgetnamed1(int what, CFDictionaryRef attrs, int param);
+ void aatprintfontname(int what, CFDictionaryRef attrs, int param1, int param2);
/* the metrics params here are really TeX 'scaled' (or MacOS 'Fixed') values, but that typedef isn't available every place this is included */
- void atsugetfontmetrics(CFDictionaryRef attrs, integer* ascent, integer* descent, integer* xheight, integer* capheight, integer* slant);
+ void aatgetfontmetrics(CFDictionaryRef attrs, integer* ascent, integer* descent, integer* xheight, integer* capheight, integer* slant);
#ifdef XETEX_MAC
@@ -319,7 +316,7 @@ extern "C" {
};
#endif
-// copied from xetex-hz.ch
+// copied from xetex.web
#define LEFT_SIDE 0
#define RIGHT_SIDE 1
diff --git a/Build/source/texk/web2c/xetexdir/XeTeX_mac.c b/Build/source/texk/web2c/xetexdir/XeTeX_mac.c
index e08556ff1b2..dc495b14648 100644
--- a/Build/source/texk/web2c/xetexdir/XeTeX_mac.c
+++ b/Build/source/texk/web2c/xetexdir/XeTeX_mac.c
@@ -102,7 +102,7 @@ DoAATLayout(void* p, int justify)
unsigned f = native_font(node);
if (fontarea[f] != AAT_FONT_FLAG) {
- fprintf(stderr, "internal error: do_atsui_layout called for non-ATSUI font\n");
+ fprintf(stderr, "internal error: DoAATLayout called for non-AAT font\n");
exit(1);
}
diff --git a/Build/source/texk/web2c/xetexdir/xetex.ch b/Build/source/texk/web2c/xetexdir/xetex.ch
index 4495d1c5774..304a3831307 100644
--- a/Build/source/texk/web2c/xetexdir/xetex.ch
+++ b/Build/source/texk/web2c/xetexdir/xetex.ch
@@ -440,7 +440,7 @@ for j:=1 to n do append_to_name(TEX_format_default[j]);
@!font_false_bchar: ^nine_bits;
{|font_bchar| if it doesn't exist in the font, otherwise |non_char|}
@#
-@!font_layout_engine: ^void_pointer; { either an ATSUStyle or a XeTeXLayoutEngine }
+@!font_layout_engine: ^void_pointer; {either an CFDictionaryRef or a XeTeXLayoutEngine}
@!font_mapping: ^void_pointer; { |TECkit_Converter| or 0 }
@!font_flags: ^char; { flags:
0x01: |font_colored|
diff --git a/Build/source/texk/web2c/xetexdir/xetex.defines b/Build/source/texk/web2c/xetexdir/xetex.defines
index 4ad5cd2abf9..efa4099a6bb 100644
--- a/Build/source/texk/web2c/xetexdir/xetex.defines
+++ b/Build/source/texk/web2c/xetexdir/xetex.defines
@@ -83,12 +83,12 @@ authorization from the copyright holders.
@define function glyphinfobyte();
@define function casttoushort();
-@define function atsufontget();
-@define function atsufontget1();
-@define function atsufontget2();
-@define function atsufontgetnamed();
-@define function atsufontgetnamed1();
-@define procedure atsuprintfontname();
+@define function aatfontget();
+@define function aatfontget1();
+@define function aatfontget2();
+@define function aatfontgetnamed();
+@define function aatfontgetnamed1();
+@define procedure aatprintfontname();
@define function otfontget();
@define function otfontget1();
@define function otfontget2();
@@ -131,7 +131,7 @@ authorization from the copyright holders.
@define function mathclassfield();
@define function mathcharfield();
-@define procedure atsugetfontmetrics();
+@define procedure aatgetfontmetrics();
@define procedure otgetfontmetrics();
@define function getencodingmodeandinfo();
diff --git a/Build/source/texk/web2c/xetexdir/xetex.web b/Build/source/texk/web2c/xetexdir/xetex.web
index 793552413d5..4e5ec76c970 100644
--- a/Build/source/texk/web2c/xetexdir/xetex.web
+++ b/Build/source/texk/web2c/xetexdir/xetex.web
@@ -12051,11 +12051,11 @@ the font.
@d otgr_font_flag=@"FFFE
@d aat_font_flag=@"FFFF
-@d is_atsu_font(#)==(font_area[#]=aat_font_flag)
+@d is_aat_font(#)==(font_area[#]=aat_font_flag)
@d is_ot_font(#)==((font_area[#]=otgr_font_flag) and (usingOpenType(font_layout_engine[#])))
@d is_gr_font(#)==((font_area[#]=otgr_font_flag) and (usingGraphite(font_layout_engine[#])))
@d is_otgr_font(#)==(font_area[#]=otgr_font_flag)
-@d is_native_font(#)==(is_atsu_font(#) or is_otgr_font(#))
+@d is_native_font(#)==(is_aat_font(#) or is_otgr_font(#))
{native fonts have |font_area| = 65534 or 65535,
which would be a string containing an invalid Unicode character}
@d is_new_mathfont(#)==((font_area[#]=otgr_font_flag) and (isOpenTypeMathFont(font_layout_engine[#])))
@@ -15865,7 +15865,7 @@ begin
print_visible_char(name_of_file[i]); { this is already UTF-8 }
incr(i);
end;
- print("' does not support Graphite. Trying ICU layout instead.");
+ print("' does not support Graphite. Trying OpenType layout instead.");
end_diagnostic(false);
end;
@@ -15876,7 +15876,7 @@ const
first_math_fontdimen = 10;
var
k, num_font_dimens: integer;
- font_engine: void_pointer; {really an ATSUStyle or XeTeXLayoutEngine}
+ font_engine: void_pointer; {really an CFDictionaryRef or XeTeXLayoutEngine}
actual_size: scaled; {|s| converted to real size, if it was negative}
p: pointer; {for temporary |native_char| node we'll create}
ascent, descent, font_slant, x_ht, cap_ht: scaled;
@@ -15938,7 +15938,7 @@ begin
font_size[font_ptr] := actual_size;
if (native_font_type_flag = aat_font_flag) then begin
- atsu_get_font_metrics(font_engine, addressof(ascent), addressof(descent),
+ aat_get_font_metrics(font_engine, addressof(ascent), addressof(descent),
addressof(x_ht), addressof(cap_ht), addressof(font_slant))
end else begin
ot_get_font_metrics(font_engine, addressof(ascent), addressof(descent),
@@ -16962,7 +16962,7 @@ begin fetch(accent_chr(q));
x:=null;
if is_native_font(cur_f) then
begin c:=cur_c; f:=cur_f;
- if not is_bottom_acc(q) then s:=compute_ot_math_accent_pos(q);
+ if not is_bottom_acc(q) then s:=compute_ot_math_accent_pos(q) else s:=0;
x:=clean_box(nucleus(q),cramped_style(cur_style)); w:=width(x); h:=height(x);
end
else if char_exists(cur_i) then
@@ -17487,12 +17487,14 @@ attach_hkern_to_new_hlist:=new_hlist(q);
end;
procedure make_scripts(@!q:pointer;@!delta:scaled);
-var p,@!s,@!x,@!y,@!z:pointer; {temporary registers for box construction}
+var p,@!x,@!y,@!z:pointer; {temporary registers for box construction}
@!shift_up,@!shift_down,@!clr,@!sub_kern,@!sup_kern:scaled; {dimensions in the calculation}
@!g:quarterword; {temporary register for native glyph id}
@!t:integer; {subsidiary size code}
@!save_f:internal_font_number;
+@!s:pointer; {temprary native character for sub/superscript}
begin p:=new_hlist(q);
+s:=null; sup_kern:=0; sub_kern:=0; g:=0;
if is_char_node(p) or is_glyph_node(p) then
begin shift_up:=0; shift_down:=0;
end
@@ -17604,7 +17606,6 @@ The following definitions should be kept in sync with \.{XeTeXOTMath.cpp}.
@<Attach subscript OpenType math kerning@>=
begin save_f:=cur_f;@/
fetch(subscr(q));
-sub_kern:=0; g:=0;
if is_new_mathfont(cur_f) then begin
s:=new_native_character(cur_f, qo(cur_c));
g:=get_native_glyph(s, 0);
@@ -17619,7 +17620,6 @@ end;
@ @<Attach superscript OpenType math kerning@>=
begin save_f:=cur_f;@/
fetch(supscr(q));
-sup_kern:=0; g:=0;
if is_new_mathfont(cur_f) then begin
s:=new_native_character(cur_f, qo(cur_c));
g:=get_native_glyph(s, 0);
@@ -29762,8 +29762,8 @@ XeTeX_version_code: cur_val:=XeTeX_version;
XeTeX_count_glyphs_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then
- cur_val:=atsu_font_get(m - XeTeX_int, font_layout_engine[n])
+ if is_aat_font(n) then
+ cur_val:=aat_font_get(m - XeTeX_int, font_layout_engine[n])
else if is_otgr_font(n) then
cur_val:=ot_font_get(m - XeTeX_int, font_layout_engine[n])
else
@@ -29773,8 +29773,8 @@ XeTeX_count_glyphs_code:
XeTeX_count_variations_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then
- cur_val:=atsu_font_get(m - XeTeX_int, font_layout_engine[n])
+ if is_aat_font(n) then
+ cur_val:=aat_font_get(m - XeTeX_int, font_layout_engine[n])
else begin
cur_val:=0;
end;
@@ -29782,8 +29782,8 @@ XeTeX_count_variations_code:
XeTeX_count_features_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then
- cur_val:=atsu_font_get(m - XeTeX_int, font_layout_engine[n])
+ if is_aat_font(n) then
+ cur_val:=aat_font_get(m - XeTeX_int, font_layout_engine[n])
else if is_gr_font(n) then
cur_val:=ot_font_get(m - XeTeX_int, font_layout_engine[n])
else
@@ -29796,11 +29796,11 @@ XeTeX_variation_max_code,
XeTeX_variation_default_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then begin
+ if is_aat_font(n) then begin
scan_int; k:=cur_val;
- cur_val:=atsu_font_get_1(m - XeTeX_int, font_layout_engine[n], k);
+ cur_val:=aat_font_get_1(m - XeTeX_int, font_layout_engine[n], k);
end else begin
- not_atsu_font_error(last_item, m, n); cur_val:=-1;
+ not_aat_font_error(last_item, m, n); cur_val:=-1;
end;
end;
@@ -29809,14 +29809,14 @@ XeTeX_is_exclusive_feature_code,
XeTeX_count_selectors_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then begin
+ if is_aat_font(n) then begin
scan_int; k:=cur_val;
- cur_val:=atsu_font_get_1(m - XeTeX_int, font_layout_engine[n], k);
+ cur_val:=aat_font_get_1(m - XeTeX_int, font_layout_engine[n], k);
end else if is_gr_font(n) then begin
scan_int; k:=cur_val;
cur_val:=ot_font_get_1(m - XeTeX_int, font_layout_engine[n], k);
end else begin
- not_atsu_gr_font_error(last_item, m, n); cur_val:=-1;
+ not_aat_gr_font_error(last_item, m, n); cur_val:=-1;
end;
end;
@@ -29824,53 +29824,53 @@ XeTeX_selector_code_code,
XeTeX_is_default_selector_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then begin
+ if is_aat_font(n) then begin
scan_int; k:=cur_val; scan_int;
- cur_val:=atsu_font_get_2(m - XeTeX_int, font_layout_engine[n], k, cur_val);
+ cur_val:=aat_font_get_2(m - XeTeX_int, font_layout_engine[n], k, cur_val);
end else if is_gr_font(n) then begin
scan_int; k:=cur_val; scan_int;
cur_val:=ot_font_get_2(m - XeTeX_int, font_layout_engine[n], k, cur_val);
end else begin
- not_atsu_gr_font_error(last_item, m, n); cur_val:=-1;
+ not_aat_gr_font_error(last_item, m, n); cur_val:=-1;
end;
end;
XeTeX_find_variation_by_name_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then begin
+ if is_aat_font(n) then begin
scan_and_pack_name;
- cur_val:=atsu_font_get_named(m - XeTeX_int, font_layout_engine[n]);
+ cur_val:=aat_font_get_named(m - XeTeX_int, font_layout_engine[n]);
end else begin
- not_atsu_font_error(last_item, m, n); cur_val:=-1;
+ not_aat_font_error(last_item, m, n); cur_val:=-1;
end;
end;
XeTeX_find_feature_by_name_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then begin
+ if is_aat_font(n) then begin
scan_and_pack_name;
- cur_val:=atsu_font_get_named(m - XeTeX_int, font_layout_engine[n]);
+ cur_val:=aat_font_get_named(m - XeTeX_int, font_layout_engine[n]);
end else if is_gr_font(n) then begin
scan_and_pack_name;
cur_val:=gr_font_get_named(m - XeTeX_int, font_layout_engine[n]);
end else begin
- not_atsu_gr_font_error(last_item, m, n); cur_val:=-1;
+ not_aat_gr_font_error(last_item, m, n); cur_val:=-1;
end;
end;
XeTeX_find_selector_by_name_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then begin
+ if is_aat_font(n) then begin
scan_int; k:=cur_val; scan_and_pack_name;
- cur_val:=atsu_font_get_named_1(m - XeTeX_int, font_layout_engine[n], k);
+ cur_val:=aat_font_get_named_1(m - XeTeX_int, font_layout_engine[n], k);
end else if is_gr_font(n) then begin
scan_int; k:=cur_val; scan_and_pack_name;
cur_val:=gr_font_get_named_1(m - XeTeX_int, font_layout_engine[n], k);
end else begin
- not_atsu_gr_font_error(last_item, m, n); cur_val:=-1;
+ not_aat_gr_font_error(last_item, m, n); cur_val:=-1;
end;
end;
@@ -29941,7 +29941,7 @@ XeTeX_glyph_index_code:
XeTeX_font_type_code:
begin
scan_font_ident; n:=cur_val;
- if is_atsu_font(n) then cur_val:=1
+ if is_aat_font(n) then cur_val:=1
else if is_ot_font(n) then cur_val:=2
else if is_gr_font(n) then cur_val:=3
else cur_val:=0;
@@ -29979,7 +29979,7 @@ begin
end;
@ @<Declare the procedure called |print_cmd_chr|@>=
-procedure not_atsu_font_error(cmd, c: integer; f: integer);
+procedure not_aat_font_error(cmd, c: integer; f: integer);
begin
print_err("Cannot use "); print_cmd_chr(cmd, c);
print(" with "); print(font_name[f]);
@@ -29987,7 +29987,7 @@ begin
error;
end;
-procedure not_atsu_gr_font_error(cmd, c: integer; f: integer);
+procedure not_aat_gr_font_error(cmd, c: integer; f: integer);
begin
print_err("Cannot use "); print_cmd_chr(cmd, c);
print(" with "); print(font_name[f]);
@@ -30058,28 +30058,28 @@ XeTeX_revision_code: do_nothing;
XeTeX_variation_name_code:
begin
scan_font_ident; fnt:=cur_val;
- if is_atsu_font(fnt) then begin
+ if is_aat_font(fnt) then begin
scan_int; arg1:=cur_val; arg2:=0;
end else
- not_atsu_font_error(convert, c, fnt);
+ not_aat_font_error(convert, c, fnt);
end;
XeTeX_feature_name_code:
begin
scan_font_ident; fnt:=cur_val;
- if is_atsu_font(fnt) or is_gr_font(fnt) then begin
+ if is_aat_font(fnt) or is_gr_font(fnt) then begin
scan_int; arg1:=cur_val; arg2:=0;
end else
- not_atsu_gr_font_error(convert, c, fnt);
+ not_aat_gr_font_error(convert, c, fnt);
end;
XeTeX_selector_name_code:
begin
scan_font_ident; fnt:=cur_val;
- if is_atsu_font(fnt) or is_gr_font(fnt) then begin
+ if is_aat_font(fnt) or is_gr_font(fnt) then begin
scan_int; arg1:=cur_val; scan_int; arg2:=cur_val;
end else
- not_atsu_gr_font_error(convert, c, fnt);
+ not_aat_gr_font_error(convert, c, fnt);
end;
XeTeX_glyph_name_code:
@@ -30104,13 +30104,13 @@ pdf_strcmp_code: print_int(cur_val);
XeTeX_revision_code: print(XeTeX_revision);
XeTeX_variation_name_code:
- if is_atsu_font(fnt) then
- atsu_print_font_name(c, font_layout_engine[fnt], arg1, arg2);
+ if is_aat_font(fnt) then
+ aat_print_font_name(c, font_layout_engine[fnt], arg1, arg2);
XeTeX_feature_name_code,
XeTeX_selector_name_code:
- if is_atsu_font(fnt) then
- atsu_print_font_name(c, font_layout_engine[fnt], arg1, arg2)
+ if is_aat_font(fnt) then
+ aat_print_font_name(c, font_layout_engine[fnt], arg1, arg2)
else if is_gr_font(fnt) then
gr_print_font_name(c, font_layout_engine[fnt], arg1, arg2);
diff --git a/Build/source/texk/web2c/xetexdir/XeTeX_ext.c b/Build/source/texk/web2c/xetexdir/XeTeX_ext.c
index aa637ff2f41..0b6644321e6 100644
--- a/Build/source/texk/web2c/xetexdir/XeTeX_ext.c
+++ b/Build/source/texk/web2c/xetexdir/XeTeX_ext.c
@@ -902,7 +902,7 @@ loadOTfont(PlatformFontRef fontRef, XeTeXFont font, Fixed scaled_size, const cha
char* script = NULL;
char* language = NULL;
hb_feature_t* features = NULL;
- char** shapers = NULL;
+ char** shapers = NULL; /* NULL-terminated array */
int nFeatures = 0;
int nShapers = 0;
@@ -932,10 +932,11 @@ loadOTfont(PlatformFontRef fontRef, XeTeXFont font, Fixed scaled_size, const cha
}
if (reqEngine == 'G') {
+ char* tmpShapers[] = {shapers[0]};
/* create a default engine so we can query the font for Graphite features;
* because of font caching, it's cheap to discard this and create the real one later */
engine = createLayoutEngine(fontRef, font, script, language,
- features, nFeatures, shapers, rgbValue, extend, slant, embolden);
+ features, nFeatures, tmpShapers, rgbValue, extend, slant, embolden);
if (engine == NULL)
return NULL;
@@ -979,7 +980,8 @@ loadOTfont(PlatformFontRef fontRef, XeTeXFont font, Fixed scaled_size, const cha
goto bad_option;
++cp3;
shapers = xrealloc(shapers, (nShapers + 1) * sizeof(char *));
- shapers[nShapers++] = strndup(cp3, cp2 - cp3);
+ shapers[nShapers] = strndup(cp3, cp2 - cp3);
+ nShapers++;
goto next_option;
}
@@ -1050,8 +1052,10 @@ loadOTfont(PlatformFontRef fontRef, XeTeXFont font, Fixed scaled_size, const cha
}
}
- if (shapers != NULL)
+ if (shapers != NULL) {
+ shapers = xrealloc(shapers, (nShapers + 1) * sizeof(char *));
shapers[nShapers] = NULL;
+ }
if (embolden != 0.0)
embolden = embolden * Fix2D(scaled_size) / 100.0;
@@ -1482,8 +1486,8 @@ grfontgetnamed1(integer what, void* pEngine, integer param)
return rval;
}
-#define XDV_FLAG_FONTTYPE_ATSUI 0x0001
-#define XDV_FLAG_FONTTYPE_ICU 0x0002
+#define XDV_FLAG_FONTTYPE_AAT 0x0001
+#define XDV_FLAG_FONTTYPE_OT 0x0002
#define XDV_FLAG_VERTICAL 0x0100
#define XDV_FLAG_COLORED 0x0200
@@ -1612,7 +1616,7 @@ makefontdef(integer f)
char *pathname;
int index;
- flags = XDV_FLAG_FONTTYPE_ATSUI;
+ flags = XDV_FLAG_FONTTYPE_AAT;
attributes = (CFDictionaryRef) fontlayoutengine[f];
font = CFDictionaryGetValue(attributes, kCTFontAttributeName);
variation = CTFontCopyVariation(font);
@@ -1661,7 +1665,7 @@ makefontdef(integer f)
#endif
if (fontarea[f] == OTGR_FONT_FLAG) {
XeTeXLayoutEngine engine;
- flags = XDV_FLAG_FONTTYPE_ICU;
+ flags = XDV_FLAG_FONTTYPE_OT;
engine = (XeTeXLayoutEngine)fontlayoutengine[f];
fontRef = getFontRef(engine);
@@ -1979,7 +1983,7 @@ get_native_glyph(void* pNode, unsigned index)
void
store_justified_native_glyphs(void* node)
{
-#ifdef XETEX_MAC /* this is only called for fonts used via ATSUI */
+#ifdef XETEX_MAC /* this is only called for AAT fonts */
(void)DoAATLayout(node, 1);
#endif
}
@@ -2143,7 +2147,7 @@ measure_native_node(void* pNode, int use_glyph_metrics)
node_height(node) = heightbase[f];
node_depth(node) = depthbase[f];
} else {
/* this iterates over the glyph data whether it comes from ATSUI or ICU layout */
FixedPoint* locations = (FixedPoint*)native_glyph_info_ptr(node);
uint16_t* glyphIDs = (uint16_t*)(locations + native_glyph_count(node));
float yMin = 65536.0;
@@ -2323,7 +2327,7 @@ double Fix2D(Fixed f)
/* these are here, not XeTeX_mac.c, because we need stubs on other platforms */
void
-atsugetfontmetrics(CFDictionaryRef attributes, integer* ascent, integer* descent, integer* xheight, integer* capheight, integer* slant)
+aatgetfontmetrics(CFDictionaryRef attributes, integer* ascent, integer* descent, integer* xheight, integer* capheight, integer* slant)
{
#ifdef XETEX_MAC
CTFontRef font = fontFromAttributes(attributes);
@@ -2337,7 +2341,7 @@ atsugetfontmetrics(CFDictionaryRef attributes, integer* ascent, integer* descent
}
int
-atsufontget(int what, CFDictionaryRef attributes)
+aatfontget(int what, CFDictionaryRef attributes)
{
int rval = -1;
@@ -2365,7 +2369,7 @@ atsufontget(int what, CFDictionaryRef attributes)
}
int
-atsufontget1(int what, CFDictionaryRef attributes, int param)
+aatfontget1(int what, CFDictionaryRef attributes, int param)
{
int rval = -1;
@@ -2456,7 +2460,7 @@ atsufontget1(int what, CFDictionaryRef attributes, int param)
}
int
-atsufontget2(int what, CFDictionaryRef attributes, int param1, int param2)
+aatfontget2(int what, CFDictionaryRef attributes, int param1, int param2)
{
int rval = -1;
@@ -2499,7 +2503,7 @@ atsufontget2(int what, CFDictionaryRef attributes, int param1, int param2)
}
int
-atsufontgetnamed(int what, CFDictionaryRef attributes)
+aatfontgetnamed(int what, CFDictionaryRef attributes)
{
int rval = -1;
@@ -2544,7 +2548,7 @@ atsufontgetnamed(int what, CFDictionaryRef attributes)
}
int
-atsufontgetnamed1(int what, CFDictionaryRef attributes, int param)
+aatfontgetnamed1(int what, CFDictionaryRef attributes, int param)
{
int rval = -1;
@@ -2569,7 +2573,7 @@ atsufontgetnamed1(int what, CFDictionaryRef attributes, int param)
}
void
-atsuprintfontname(int what, CFDictionaryRef attributes, int param1, int param2)
+aatprintfontname(int what, CFDictionaryRef attributes, int param1, int param2)
{
#ifdef XETEX_MAC
CTFontRef font = fontFromAttributes(attributes);
@@ -2143,7 +2147,7 @@ measure_native_node(void* pNode, int use_glyph_metrics)
node_depth(node) = depthbase[f];
} else {
- /* this iterates over the glyph data whether it comes from ATSUI or ICU layout */
+ /* this iterates over the glyph data whether it comes from AAT or OT layout */
FixedPoint* locations = (FixedPoint*)native_glyph_info_ptr(node);
uint16_t* glyphIDs = (uint16_t*)(locations + native_glyph_count(node));